searchData={"items":[{"type":"module","title":"IgniterJs.Helpers","doc":"A module that contains helper functions for IgniterJs. For example it helps to normalize the\noutput of the NIFs, read and validate the file, and call the NIF function with the\ngiven file path or content.","ref":"IgniterJs.Helpers.html"},{"type":"function","title":"IgniterJs.Helpers.call_nif_fn/4","doc":"Call the NIF function with the given file path or content and return the result.\nIt helps to change the function name as atom based on its caller function.\n\n```elixir\ncall_nif_fn(\"/path/to/file.js\", __ENV__.function, fn content -> content end, :path)\ncall_nif_fn(\"file content\", __ENV__.function, fn content -> content end)\ncall_nif_fn(\"file content\", __ENV__.function, fn content -> content end, :content)\n```","ref":"IgniterJs.Helpers.html#call_nif_fn/4"},{"type":"macro","title":"IgniterJs.Helpers.normalize_output/2","doc":"Normalize the output of the NIFs. It is a macro and returns a tuple with the first\nelement as the output, the second element as the caller function name, and the\nthird element as the status.\n\n```elixir\nrequire IgniterJs.Helpers\nnormalize_output({:ok, :fun_atom, result}, __ENV__.function)\nnormalize_output({:error, :fun_atom, result}, __ENV__.function)\n```","ref":"IgniterJs.Helpers.html#normalize_output/2"},{"type":"function","title":"IgniterJs.Helpers.read_and_validate_file/1","doc":"Read and validate the file. It returns the file content if the file exists and the\nextension is `.js` or `.ts`, otherwise, it returns an error tuple.\n\n```elixir\nread_and_validate_file(\"/path/to/file.js\")\n```","ref":"IgniterJs.Helpers.html#read_and_validate_file/1"},{"type":"module","title":"IgniterJs.Parsers.Javascript.Parser","doc":"Codemods for JavaScript files.","ref":"IgniterJs.Parsers.Javascript.Parser.html"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.exist_live_socket/2","doc":"Check if a LiveSocket var exists in the given file or content and returns tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.exist_live_socket(js_content)\nParser.exist_live_socket(js_content, :content)\nParser.exist_live_socket(\"/path/to/file.js\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#exist_live_socket/2"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.exist_live_socket?/2","doc":"Check if a LiveSocket var exists in the given file or content and returns boolean.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.exist_live_socket?(js_content)\nParser.exist_live_socket?(js_content, :content)\nParser.exist_live_socket?(\"/path/to/file.js\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#exist_live_socket?/2"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.extend_hook_object/3","doc":"Extend the hook object in the given file or content. It accepts a single object\nor a list of objects.\nIt returns a tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.extend_hook_object(js_content, \"SomeObject\")\nParser.extend_hook_object(js_content, [\"SomeObject\", \"AnotherObject\"], :content)\nParser.extend_hook_object(\"/path/to/file.js\", \"SomeObject\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#extend_hook_object/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.insert_imports/3","doc":"Insert imports to the given file or content and returns tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.insert_imports(js_content, imports_lines)\nParser.insert_imports(js_content, imports_lines, :content)\nParser.insert_imports(\"/path/to/file.js\", imports_lines, :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#insert_imports/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.module_imported/3","doc":"Check if a module is imported in the given file or content or contents and return tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.module_imported(js_content, \"module\")\nParser.module_imported(js_content, \"module\", :content)\nParser.module_imported(\"/path/to/file.js\", \"module\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#module_imported/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.module_imported?/3","doc":"Check if a module is imported in the given file or content or content and returns boolean.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.module_imported?(js_content, \"module\")\nParser.module_imported?(js_content, \"module\", :content)\nParser.module_imported?(\"/path/to/file.js\", \"module\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#module_imported?/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.remove_imports/3","doc":"Remove imports from the given file or content. it accepts a single module or a list of modules.\nIt returns a tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.remove_imports(js_content, \"SomeModule\")\nParser.remove_imports(js_content, [\"SomeModule\", \"AnotherModule\"], :content)\nParser.remove_imports(\"/path/to/file.js\", \"SomeModule\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#remove_imports/3"},{"type":"function","title":"IgniterJs.Parsers.Javascript.Parser.remove_objects_from_hooks/3","doc":"Remove objects from the hooks in the given file or content. It accepts a single o\nbject or a list of objects.\nIt returns a tuple.\n\n```elixir\nalias IgniterJs.Parsers.Javascript.Parser\nParser.remove_objects_from_hooks(js_content, \"SomeObject\")\nParser.remove_objects_from_hooks(js_content, [\"SomeObject\", \"AnotherObject\"], :content)\nParser.remove_objects_from_hooks(\"/path/to/file.js\", \"SomeObject\", :path)\n```","ref":"IgniterJs.Parsers.Javascript.Parser.html#remove_objects_from_hooks/3"},{"type":"extras","title":"Home","doc":"[![CI](https://github.com/ash-project/igniter/actions/workflows/elixir.yml/badge.svg)](https://github.com/ash-project/igniter/actions/workflows/elixir.yml)\n[![Hex version badge](https://img.shields.io/hexpm/v/igniter.svg)](https://hex.pm/packages/igniter)\n[![Hexdocs badge](https://img.shields.io/badge/docs-hexdocs-purple)](https://hexdocs.pm/igniter)\n\n# IgniterJs\n\nIgniterJs is javascript patching functionality for [Igniter](https://hexdocs.pm/ash/igniter)","ref":"readme.html"},{"type":"extras","title":"Installation - Home","doc":"IgniterJs can be added to an existing elixir project by adding it to your dependencies:\n\n```elixir\n{:igniter_js, \"~> 0.1\", only: [:dev, :test]}\n```","ref":"readme.html#installation"},{"type":"extras","title":"Status - Home","doc":"We are still working on getting this ready for an initial release.\n\nThe initial codemods will be limited to specific transformations. This is not intended to\nbe a toolkit (yet) for writing any arbitrary transformation like `Igniter` is for `Elixir`.\nWe will likely provide a way to do this by the user providing rust code and using our tools\nto hook it up to igniter.","ref":"readme.html#status"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n\n## [v0.1.2](https://github.com/ash-project/igniter_js/compare/v0.1.1...v0.1.2) (2024-12-29)","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes - Change Log","doc":"- Properly include all checksums\n\n\n\n## [v0.1.1](https://github.com/ash-project/igniter_js/compare/v0.1.0...v0.1.1) (2024-12-29)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* Support RustlerPrecompiled release (#3)\n\n## [v0.1.0](https://github.com/ash-project/igniter_js/compare/v0.1.0...v0.1.0) (2024-12-24)","ref":"changelog.html#improvements"},{"type":"extras","title":"Features: - Change Log","doc":"* OXC wrapper NIF & initial features","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}